aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/platforms/AVR
diff options
context:
space:
mode:
authorgdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2011-12-31 10:07:43 +0000
committergdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2011-12-31 10:07:43 +0000
commitc397738010966f85c7ae841e21d74790ac49611c (patch)
tree71fc62ea0e2f86481586f51dbe55ffe691b4b363 /os/hal/platforms/AVR
parent72266f8b591c6e7857f4578ba753eeea7222ac6b (diff)
downloadChibiOS-c397738010966f85c7ae841e21d74790ac49611c.tar.gz
ChibiOS-c397738010966f85c7ae841e21d74790ac49611c.tar.bz2
ChibiOS-c397738010966f85c7ae841e21d74790ac49611c.zip
Changes to palSetGroupMode(), various adjustments to the PAL driver.
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@3695 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'os/hal/platforms/AVR')
-rw-r--r--os/hal/platforms/AVR/pal_lld.h28
1 files changed, 15 insertions, 13 deletions
diff --git a/os/hal/platforms/AVR/pal_lld.h b/os/hal/platforms/AVR/pal_lld.h
index fe64029d0..b04241dbf 100644
--- a/os/hal/platforms/AVR/pal_lld.h
+++ b/os/hal/platforms/AVR/pal_lld.h
@@ -65,7 +65,7 @@ typedef struct {
* @brief AVR registers block.
* @note On some devices registers do not follow this layout on some
* ports, the ports with abnormal layout cannot be used through
- * the PAL driver. Example: PORT F on Mega128.
+ * PAL driver. Example: PORT F on Mega128.
*/
typedef struct {
volatile uint8_t in;
@@ -192,7 +192,7 @@ typedef avr_gpio_registers_t *ioportid_t;
/**
* @brief Reads the physical I/O port states.
*
- * @param[in] port the port identifier
+ * @param[in] port port identifier
* @return The port bits.
*
* @notapi
@@ -204,7 +204,7 @@ typedef avr_gpio_registers_t *ioportid_t;
* @details The purpose of this function is to read back the latched output
* value.
*
- * @param[in] port the port identifier
+ * @param[in] port port identifier
* @return The latched logical states.
*
* @notapi
@@ -214,8 +214,8 @@ typedef avr_gpio_registers_t *ioportid_t;
/**
* @brief Writes a bits mask on a I/O port.
*
- * @param[in] port the port identifier
- * @param[in] bits the bits to be written on the specified port
+ * @param[in] port port identifier
+ * @param[in] bits bits to be written on the specified port
*
* @notapi
*/
@@ -227,19 +227,21 @@ typedef avr_gpio_registers_t *ioportid_t;
* with the specified mode.
* @note Programming an unknown or unsupported mode is silently ignored.
*
* @param[in] port the port identifier
* @param[in] mask the group mask
* @param[in] mode the mode
*
* @notapi
*/
-#define pal_lld_setgroupmode(port, mask, mode) _pal_lld_setgroupmode(port, mask, mode)
+#define pal_lld_setgroupmode(port, mask, offset, mode) \
+ _pal_lld_setgroupmode(port, mask << offset, mode)
/**
* @brief Sets a pad logical state to @p PAL_HIGH.
*
- * @param[in] port the port identifier
- * @param[in] pad the pad number within the port
+ * @param[in] port port identifier
+ * @param[in] pad pad number within the port
*
* @notapi
*/
@@ -256,8 +258,8 @@ __asm__ __volatile__ \
/**
* @brief Clears a pad logical state to @p PAL_LOW.
*
- * @param[in] port the port identifier
- * @param[in] pad the pad number within the port
+ * @param[in] port port identifier
+ * @param[in] pad pad number within the port
*
* @notapi
*/
@@ -227,19 +227,21 @@ typedef avr_gpio_registers_t *ioportid_t;
* @note Programming an unknown or unsupported mode is silently ignored.
*
- * @param[in] port the port identifier
- * @param[in] mask the group mask
- * @param[in] mode the mode
+ * @param[in] port port identifier
+ * @param[in] mask group mask
+ * @param[in] offset group bit offset within the port
+ * @param[in] mode group mode
*
* @notapi